* Political Institutions and Collective Attachments, Replication File for Appendix

clear

* Set the appropriate directory
* cd ... 

set more off

use "Main_Data.dta"

********************************************************************************

* Table SA1: Bivariate Correlations
corr EU_Attachment European_Attachment EU_Citizenship European_Identification

********************************************************************************

* Table SA2: Results from Factor Analysis
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf

predict Identity_Scale

* Cronbach's Alpha
alpha EU_Attachment European_Attachment EU_Citizenship European_Identification

********************************************************************************

* Table SA3: Predicted Probabilities, State Structure
***** EU_Attachment *****
quietly meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "Not at all attached" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "Not at all attached" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "Not at all attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "Not very attached" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "Not very attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Fairly Attached" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Fairly Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Very Attached" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Very Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Attachment *****
quietly meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "Not at all attached" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "Not at all attached" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "Not at all attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "Not very attached" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "Not very attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Fairly Attached" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Fairly Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Very Attached" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Very Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** EU_Citizenship *****
quietly meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "No, definitely not" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "No, definitely not" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "No, definitely not" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "No, not really" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "No, not really" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "No, not really" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Yes, to some extent" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Yes, to some extent" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Yes, to some extent" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Yes, definitely" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Yes, definitely" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Yes, definitely" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Identification *****
quietly meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "(NATIONALITY) only" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "(NATIONALITY) only" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "(NATIONALITY) only" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "(NATIONALITY) and European" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "(NATIONALITY) and European" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "(NATIONALITY) and European" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "European and (NATIONALITY)" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "European and (NATIONALITY)" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "European and (NATIONALITY)" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "European only" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "European only" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "European only" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)

********************************************************************************

tabulate Country, summarize(Regional_Authority_Index)
* Portugal: 3.8038291
* Spain: 33.556522

* Table SA4: Predicted Probabilities, Regional Authority Index
***** EU_Attachment *****
quietly meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not at all attached" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "Not at all attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not very attached" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "Not very attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Fairly Attached" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Fairly Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Very Attached" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Very Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Attachment *****
quietly meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not at all attached" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "Not at all attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not very attached" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "Not very attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Fairly Attached" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Fairly Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Very Attached" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Very Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** EU_Citizenship *****
quietly meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "No, definitely not" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "No, definitely not" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "No, definitely not" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "No, not really" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "No, not really" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "No, not really" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Yes, to some extent" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Yes, to some extent" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Yes, to some extent" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Yes, definitely" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Yes, definitely" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Yes, definitely" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Identification *****
quietly meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "(NATIONALITY) only" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "(NATIONALITY) only" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "(NATIONALITY) only" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "(NATIONALITY) and European" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "(NATIONALITY) and European" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "(NATIONALITY) and European" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "European and (NATIONALITY)" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "European and (NATIONALITY)" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "European and (NATIONALITY)" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "European only" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "European only" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "European only" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)

********************************************************************************

summarize Regional_Authority_Index
* Mean: 12.20802
* SD: 10.95945

display 12.20802 + 10.95945
* Mean: 12.20802
* Mean + 1 SD: 23.16747

* Table SA5: Predicted Probabilities, Regional Authority Index at Mean and One Standard Deviation above the Mean
***** EU_Attachment *****
quietly meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Mean (12.21)
margins, predict(outcome(1)) at(Regional_Authority_Index =12.20802) atmeans
* "Not at all attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(1)) at(Regional_Authority_Index =23.16747) atmeans
* "Not at all attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Mean (12.21)
margins, predict(outcome(2)) at(Regional_Authority_Index =12.20802) atmeans
* "Not very attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(2)) at(Regional_Authority_Index =23.16747) atmeans
* "Not very attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Mean (12.21)
margins, predict(outcome(3)) at(Regional_Authority_Index =12.20802) atmeans
* "Fairly Attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(3)) at(Regional_Authority_Index =23.16747) atmeans
* "Fairly Attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Mean (12.21)
margins, predict(outcome(4)) at(Regional_Authority_Index =12.20802) atmeans
* "Very Attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(4)) at(Regional_Authority_Index =23.16747) atmeans
* "Very Attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Attachment *****
quietly meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Mean (12.21)
margins, predict(outcome(1)) at(Regional_Authority_Index =12.20802) atmeans
* "Not at all attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(1)) at(Regional_Authority_Index =23.16747) atmeans
* "Not at all attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Mean (12.21)
margins, predict(outcome(2)) at(Regional_Authority_Index =12.20802) atmeans
* "Not very attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(2)) at(Regional_Authority_Index =23.16747) atmeans
* "Not very attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Mean (12.21)
margins, predict(outcome(3)) at(Regional_Authority_Index =12.20802) atmeans
* "Fairly Attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(3)) at(Regional_Authority_Index =23.16747) atmeans
* "Fairly Attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Mean (12.21)
margins, predict(outcome(4)) at(Regional_Authority_Index =12.20802) atmeans
* "Very Attached" -- Mean + 1 SD (23.17)
margins, predict(outcome(4)) at(Regional_Authority_Index =23.16747) atmeans
* "Very Attached" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(4)) atmeans contrast(at effects)


***** EU_Citizenship *****
quietly meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "No, definitely not" -- Mean (12.21)
margins, predict(outcome(1)) at(Regional_Authority_Index =12.20802) atmeans
* "No, definitely not" -- Mean + 1 SD (23.17)
margins, predict(outcome(1)) at(Regional_Authority_Index =23.16747) atmeans
* "No, definitely not" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(1)) atmeans contrast(at effects)

* "No, not really" -- Mean (12.21)
margins, predict(outcome(2)) at(Regional_Authority_Index =12.20802) atmeans
* "No, not really" -- Mean + 1 SD (23.17)
margins, predict(outcome(2)) at(Regional_Authority_Index =23.16747) atmeans
* "No, not really" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(2)) atmeans contrast(at effects)

* "Yes, to some extent" -- Mean (12.21)
margins, predict(outcome(3)) at(Regional_Authority_Index =12.20802) atmeans
* "Yes, to some extent" -- Mean + 1 SD (23.17)
margins, predict(outcome(3)) at(Regional_Authority_Index =23.16747) atmeans
* "Yes, to some extent" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(3)) atmeans contrast(at effects)

* "Yes, definitely" -- Mean (12.21)
margins, predict(outcome(4)) at(Regional_Authority_Index =12.20802) atmeans
* "Yes, definitely" -- Mean + 1 SD (23.17)
margins, predict(outcome(4)) at(Regional_Authority_Index =23.16747) atmeans
* "Yes, definitely" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Identification *****
quietly meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode: 

* "(NATIONALITY) only" -- Mean (12.21)
margins, predict(outcome(1)) at(Regional_Authority_Index =12.20802) atmeans
* "(NATIONALITY) only" -- Mean + 1 SD (23.17)
margins, predict(outcome(1)) at(Regional_Authority_Index =23.16747) atmeans
* "(NATIONALITY) only" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(1)) atmeans contrast(at effects)

* "(NATIONALITY) and European" -- Mean (12.21)
margins, predict(outcome(2)) at(Regional_Authority_Index =12.20802) atmeans
* "(NATIONALITY) and European" -- Mean + 1 SD (23.17)
margins, predict(outcome(2)) at(Regional_Authority_Index =23.16747) atmeans
* "(NATIONALITY) and European" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(2)) atmeans contrast(at effects)

* "European and (NATIONALITY)" -- Mean (12.21)
margins, predict(outcome(3)) at(Regional_Authority_Index =12.20802) atmeans
* "European and (NATIONALITY)" -- Mean + 1 SD (23.17)
margins, predict(outcome(3)) at(Regional_Authority_Index =23.16747) atmeans
* "European and (NATIONALITY)" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(3)) atmeans contrast(at effects)

* "European only" -- Mean (12.21)
margins, predict(outcome(4)) at(Regional_Authority_Index =12.20802) atmeans
* "European only" -- Mean + 1 SD (23.17)
margins, predict(outcome(4)) at(Regional_Authority_Index =23.16747) atmeans
* "European only" -- First Difference ((Mean + 1 SD) - Mean)
margins, at(Regional_Authority_Index=(12.20802 23.16747)) predict(outcome(4)) atmeans contrast(at effects)

********************************************************************************

clear
use "data_Belgium.dta"

* Table SA6: Over-Time Analysis of Regional Authority and Identification, Belgium
* Model 1
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_Current || Version:

* Model 2 
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_1YearLag || Version:

* Model 3 
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_2YearAverage || Version:

********************************************************************************

clear
use "data_Italy.dta" 

* Table SA7: Over-Time Analysis of Regional Authority and Identification, Italy
* Model 1
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_Current || Version:

* Model 2 
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_1YearLag || Version:

* Model 3 
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_2YearAverage || Version:

********************************************************************************

clear
use "data_UK.dta"

* Table SA8: Over-Time Analysis of Regional Authority and Identification, United Kingdom
* Model 1
meologit European_Identification Male Age Education GDP_per_capita RAI_Current || Version:

* Model 2 
meologit European_Identification Male Age Education GDP_per_capita RAI_1YearLag || Version:

* Model 3 
meologit European_Identification Male Age Education GDP_per_capita RAI_2YearAverage || Version:

********************************************************************************

clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

* Table SA9: Multilevel Linear Models Using Identity Scale as DependentVariable, Controlling for the Number of Politically Relevant Ethnic Groups
* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone EPR_Groups Federal_State || CountryCode:, variance

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone EPR_Groups Regional_Authority_Index || CountryCode:, variance

********************************************************************************

* Table SA10: Multilevel Linear Models Using Identity Scale as Dependent Variable, Controlling for Regionalist Party Strength
* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Eurozone ELF Regionalist_Party_Strength Federal_State || CountryCode:, variance

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Eurozone ELF Regionalist_Party_Strength Regional_Authority_Index || CountryCode:, variance

********************************************************************************

* Table SA11: Multilevel Linear Models Using Identity Scale as Dependent Variable, Dropping Influential Countries (Cook’s D > 4/N)
quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance
mltcooksd
* Information found under "Level-two units with Cook's D above the cut off value:"
* Influential Country Codes: 28, 12, 15, 26, 10, 13, 3, 4, 18, 7
drop if CountryCode == 28
drop if CountryCode == 12
drop if CountryCode == 15
drop if CountryCode == 26
drop if CountryCode == 10
drop if CountryCode == 13
drop if CountryCode == 3
drop if CountryCode == 4
drop if CountryCode == 18
drop if CountryCode == 7

* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance


clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance
mltcooksd
* Information found under "Level-two units with Cook's D above the cut off value:"
* Influential Country Codes: 28, 12, 15, 26, 18, 10, 13, 3, 4, 7, 22
drop if CountryCode == 28
drop if CountryCode == 12
drop if CountryCode == 15
drop if CountryCode == 26
drop if CountryCode == 18
drop if CountryCode == 10
drop if CountryCode == 13
drop if CountryCode == 3
drop if CountryCode == 4
drop if CountryCode == 7
drop if CountryCode == 22

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance

********************************************************************************

clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

* Table SA12: Multilevel Linear Models Using Identity Scale as DependentVariable, Dropping Influential Observations (Cook’s D > 4/N)
quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance
predict cooksd
drop if cooksd > 4/20097

* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance


clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance
predict cooksd
drop if cooksd > 4/20097

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance

********************************************************************************

clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

* Table SA13: Multilevel Linear Models Using Identity Scale as DependentVariable, Dropping Influential Observations (Cook’s D > 1)
quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance
predict cooksd
drop if cooksd > 1

* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance


clear
use "Main_Data.dta"
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf
predict Identity_Scale

quietly xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance
predict cooksd
drop if cooksd > 1

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance
