# Political Institutions and Collective Attachments, Replication File for Figure 1

# Set the appropriate directory
# setwd("")

data <- read.csv("Figure_1.csv")

data$Country <- as.character(data$Country)
unique(data$Country)

names(data)

meanRAI <- tapply(data$Regional_Authority_Index, data$Country, FUN=mean)
meanIdentity <- tapply(data$Identity_Scale, data$Country, FUN=mean, na.rm=T)

meanAll <- as.data.frame(cbind(meanRAI, meanIdentity))

meanUnitary <- meanAll[-c(1,2,11,15,26),]
meanFederal <- meanAll[c(1,2,11,15,26),]

plot(meanUnitary$meanIdentity ~ meanUnitary$meanRAI, xlab="",
     ylab="", pch=19, xlim=c(0,40), ylim=c(-0.75, 0.85), cex=0.75,
     cex.lab=1, cex.axis=1, yaxt="n")
title(xlab="Regional Authority Index", line=2.5)
title(ylab="Identity Scale", line=2.5)
axis(2, at=c(-0.75, -0.35, 0.05, 0.45, 0.85))
points(meanFederal$meanIdentity ~ meanFederal$meanRAI, pch=17, cex=0.75)

legend("bottomright", legend=c("Federal State", "Unitary State"), pch=c(17,19), cex=0.75)

title(expression("Figure 1: State Structure and Identity"), line=1)

abline(lm(meanIdentity~meanRAI), lwd=2)

# The identify() function is used to label data points. After running the line of code
# below, click on each data point in order to identify the country.
identify(x=meanRAI, y=meanIdentity, n=28, labels=row.names(meanAll), cex=0.6)

# Descriptive statistics comparing federal states to unitary ones.
# Federal states (mean value of Identity Scale for federal states)
mean(data[data$Federal_State == 1, "Identity_Scale"], na.rm=T) # 0.1794707

# Unitary states (mean value of Identity Scale for unitary states)
mean(data[data$Federal_State == 0, "Identity_Scale"], na.rm=T) # -0.04484674

