* Political Institutions and Collective Attachments, Replication File for Main Text

clear

* Set the appropriate directory
* cd ... 

set more off

use "Main_Data.dta"

* Create Identity Scale
factor EU_Attachment European_Attachment EU_Citizenship European_Identification, pcf

predict Identity_Scale

********************************************************************************

* Table 1: State Structure and Regional Authority
* Federal State / Unitary State
tabulate Country, summarize(Federal_State)

* Regional Authority Index
tabulate Country, summarize(Regional_Authority_Index)

********************************************************************************

* Table 2: Multilevel Linear Models Using Identity Scale as Dependent Variable
* Model 1
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:, variance

* Model 2
xtmixed Identity_Scale Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:, variance

********************************************************************************

* Table 3: Multilevel Ordered Logit Models Using Disaggregated Measures I
* Model 1
meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* Model 2
meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* Model 3
meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* Model 4
meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

********************************************************************************

* Table 4: Multilevel Ordered Logit Models Using Disaggregated Measures II
* Model 1
meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* Model 2
meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* Model 3
meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* Model 4
meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

********************************************************************************

* Table 5: Predicted Probabilities, State Structure
***** EU_Attachment *****
quietly meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "Not at all attached" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "Not at all attached" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "Not at all attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "Not very attached" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "Not very attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Fairly Attached" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Fairly Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Very Attached" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Very Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Attachment *****
quietly meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode: 

* "Not at all attached" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "Not at all attached" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "Not at all attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "Not very attached" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "Not very attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Fairly Attached" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Fairly Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Very Attached" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Very Attached" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** EU_Citizenship *****
quietly meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "No, definitely not" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "No, definitely not" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "No, definitely not" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "No, not really" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "No, not really" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "No, not really" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "Yes, to some extent" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "Yes, to some extent" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "Yes, to some extent" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "Yes, definitely" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "Yes, definitely" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "Yes, definitely" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Identification *****
quietly meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Federal_State || CountryCode:

* "(NATIONALITY) only" -- Unitary State
margins, predict(outcome(1)) at(Federal_State =0) atmeans
* "(NATIONALITY) only" -- Federal State
margins, predict(outcome(1)) at(Federal_State =1) atmeans
* "(NATIONALITY) only" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(1)) atmeans contrast(at effects)

* "(NATIONALITY) and European" -- Unitary State
margins, predict(outcome(2)) at(Federal_State =0) atmeans
* "(NATIONALITY) and European" -- Federal State
margins, predict(outcome(2)) at(Federal_State =1) atmeans
* "(NATIONALITY) and European" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(2)) atmeans contrast(at effects)

* "European and (NATIONALITY)" -- Unitary State
margins, predict(outcome(3)) at(Federal_State =0) atmeans
* "European and (NATIONALITY)" -- Federal State
margins, predict(outcome(3)) at(Federal_State =1) atmeans
* "European and (NATIONALITY)" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(3)) atmeans contrast(at effects)

* "European only" -- Unitary State
margins, predict(outcome(4)) at(Federal_State =0) atmeans
* "European only" -- Federal State
margins, predict(outcome(4)) at(Federal_State =1) atmeans
* "European only" -- First Difference (Federal - Unitary)
margins, at(Federal_State=(0 1)) predict(outcome(4)) atmeans contrast(at effects)

********************************************************************************

tabulate Country, summarize(Regional_Authority_Index)
* Portugal: 3.8038291
* Spain: 33.556522

* Table 6: Predicted Probabilities, Regional Authority Index
***** EU_Attachment *****
quietly meologit EU_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not at all attached" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "Not at all attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not very attached" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "Not very attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Fairly Attached" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Fairly Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Very Attached" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Very Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Attachment *****
quietly meologit European_Attachment Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "Not at all attached" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not at all attached" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "Not at all attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "Not very attached" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "Not very attached" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "Not very attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Fairly Attached" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Fairly Attached" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Fairly Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Very Attached" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Very Attached" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Very Attached" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** EU_Citizenship *****
quietly meologit EU_Citizenship Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode:

* "No, definitely not" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "No, definitely not" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "No, definitely not" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "No, not really" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "No, not really" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "No, not really" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "Yes, to some extent" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "Yes, to some extent" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "Yes, to some extent" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "Yes, definitely" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "Yes, definitely" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "Yes, definitely" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)


***** European_Identification *****
quietly meologit European_Identification Male Age Education Material_Wealth Native EU_Knowledge EU_Trust Opinion_on_Membership GDP_per_capita Membership_Duration Post_Communist Eurozone ELF Regional_Authority_Index || CountryCode: 

* "(NATIONALITY) only" -- Low (3.80)
margins, predict(outcome(1)) at(Regional_Authority_Index =3.8038291) atmeans
* "(NATIONALITY) only" -- High (33.56)
margins, predict(outcome(1)) at(Regional_Authority_Index =33.556522) atmeans
* "(NATIONALITY) only" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(1)) atmeans contrast(at effects)

* "(NATIONALITY) and European" -- Low (3.80)
margins, predict(outcome(2)) at(Regional_Authority_Index =3.8038291) atmeans
* "(NATIONALITY) and European" -- High (33.56)
margins, predict(outcome(2)) at(Regional_Authority_Index =33.556522) atmeans
* "(NATIONALITY) and European" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(2)) atmeans contrast(at effects)

* "European and (NATIONALITY)" -- Low (3.80)
margins, predict(outcome(3)) at(Regional_Authority_Index =3.8038291) atmeans
* "European and (NATIONALITY)" -- High (33.56)
margins, predict(outcome(3)) at(Regional_Authority_Index =33.556522) atmeans
* "European and (NATIONALITY)" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(3)) atmeans contrast(at effects)

* "European only" -- Low (3.80)
margins, predict(outcome(4)) at(Regional_Authority_Index =3.8038291) atmeans
* "European only" -- High (33.56)
margins, predict(outcome(4)) at(Regional_Authority_Index =33.556522) atmeans
* "European only" -- First Difference (High - Low)
margins, at(Regional_Authority_Index=(3.8038291 33.556522)) predict(outcome(4)) atmeans contrast(at effects)

********************************************************************************

clear

* Table 7: Over-Time Analysis of Regional Authority and European Identification
* Model 1: Belgium
use "data_Belgium.dta"
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_Current || Version:

clear

* Model 2: Italy
use "data_Italy.dta"
meologit European_Identification Male Age Education GDP_per_capita Eurozone RAI_Current || Version:

clear

* Model 3: United Kingdom
use "data_UK.dta"
meologit European_Identification Male Age Education GDP_per_capita RAI_Current || Version:

********************************************************************************

